==> ejc-businessplan-impl-3.0.0-20230330.074522-144-sources.jar: com/ejianc/business/busniessplan/vo/FundrecoveryplanningdetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目资金回收流程策划子表
 * 
 * @author generator
 * 
 */
public class FundrecoveryplanningdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String remarks; // 备注
    private java.lang.String process; // 流程
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date contractStartEndTime; // 合同约定申付起止时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date planStartEndTime; // 策划申付起止时间
    private java.lang.String reviewers; // 审核人员
    private java.lang.String docking; // 项目部跟踪、对接责任人员
    private java.lang.String response; // 应对措施
    private java.lang.String paymentStartEndTime; // 合同约定申付起止时间
    private java.lang.String payStartEndTime; // 策划申付起止时间


    /**
     * 策划申付起止时间
     * @return
     */
    public String getPayStartEndTime() {
        return payStartEndTime;
    }

    /**
     * 策划申付起止时间
     * @param payStartEndTime
     */
    public void setPayStartEndTime(String payStartEndTime) {
        this.payStartEndTime = payStartEndTime;
    }


    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 流程
     */
    public java.lang.String getProcess() {
        return process;
    }

    /**
     * 流程
     */
    public void setProcess(java.lang.String process) {
        this.process = process;
    }
    /**
     * 合同约定申付起止时间
     */
    public java.util.Date getContractStartEndTime() {
        return contractStartEndTime;
    }

    /**
     * 合同约定申付起止时间
     */
    public void setContractStartEndTime(java.util.Date contractStartEndTime) {
        this.contractStartEndTime = contractStartEndTime;
    }

    public String getPaymentStartEndTime() {
        return paymentStartEndTime;
    }

    public void setPaymentStartEndTime(String paymentStartEndTime) {
        this.paymentStartEndTime = paymentStartEndTime;
    }

    /**
     * 策划申付起止时间
     */
    public java.util.Date getPlanStartEndTime() {
        return planStartEndTime;
    }

    /**
     * 策划申付起止时间
     */
    public void setPlanStartEndTime(java.util.Date planStartEndTime) {
        this.planStartEndTime = planStartEndTime;
    }
    /**
     * 审核人员
     */
    public java.lang.String getReviewers() {
        return reviewers;
    }

    /**
     * 审核人员
     */
    public void setReviewers(java.lang.String reviewers) {
        this.reviewers = reviewers;
    }
    /**
     * 项目部跟踪、对接责任人员
     */
    public java.lang.String getDocking() {
        return docking;
    }

    /**
     * 项目部跟踪、对接责任人员
     */
    public void setDocking(java.lang.String docking) {
        this.docking = docking;
    }
    /**
     * 应对措施
     */
    public java.lang.String getResponse() {
        return response;
    }

    /**
     * 应对措施
     */
    public void setResponse(java.lang.String response) {
        this.response = response;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20251020.072741-223-sources.jar: com/ejianc/business/busniessplan/vo/FundrecoveryplanningdetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目资金回收流程策划子表
 *
 * @author generator
 *
 */
public class FundrecoveryplanningdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String remarks; // 备注
    private java.lang.String process; // 流程
    private java.lang.String contractStartEndTime; // 合同约定申付起止时间
    private java.lang.String planStartEndTime; // 策划申付起止时间
    private java.lang.String reviewers; // 审核人员
    private java.lang.String docking; // 项目部跟踪、对接责任人员
    private java.lang.String response; // 应对措施





    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 流程
     */
    public java.lang.String getProcess() {
        return process;
    }

    /**
     * 流程
     */
    public void setProcess(java.lang.String process) {
        this.process = process;
    }
    /**
     * 合同约定申付起止时间
     */
    public java.lang.String getContractStartEndTime() {
        return contractStartEndTime;
    }

    /**
     * 合同约定申付起止时间
     */
    public void setContractStartEndTime(java.lang.String contractStartEndTime) {
        this.contractStartEndTime = contractStartEndTime;
    }


    /**
     * 策划申付起止时间
     */
    public java.lang.String getPlanStartEndTime() {
        return planStartEndTime;
    }

    /**
     * 策划申付起止时间
     */
    public void setPlanStartEndTime(java.lang.String planStartEndTime) {
        this.planStartEndTime = planStartEndTime;
    }
    /**
     * 审核人员
     */
    public java.lang.String getReviewers() {
        return reviewers;
    }

    /**
     * 审核人员
     */
    public void setReviewers(java.lang.String reviewers) {
        this.reviewers = reviewers;
    }
    /**
     * 项目部跟踪、对接责任人员
     */
    public java.lang.String getDocking() {
        return docking;
    }

    /**
     * 项目部跟踪、对接责任人员
     */
    public void setDocking(java.lang.String docking) {
        this.docking = docking;
    }
    /**
     * 应对措施
     */
    public java.lang.String getResponse() {
        return response;
    }

    /**
     * 应对措施
     */
    public void setResponse(java.lang.String response) {
        this.response = response;
    }

}
